--------------------------------------------------------------------------------
-- Copyright  2021								|
-- All Rights Reserved.								|
-- 										|
-- Permission to use, copy, modify, and distribute this software in any way	|
-- is not granted without expressed written agreement. This copyright applies	|
-- to the all code, data and artwork related to this project and all associated	|
-- projects published by the author.						|
--										|
-- More information on copyright is available from sources on-line.		|
-- Use an actual factual one!							|
--------------------------------------------------------------------------------

local _, NS = ...

local AddonName = "Dominos"

local floor = math.floor

local ConfigVersion = 1
-- ConfigFunc shoulkd be replaced with local ConfigFunc(CopyTable, settings)
--	the stuff below
-- end
-- See: FauxMazzle\Modules\AddOns.lua where this is RunScript..ed
local ConfigFunc = {
	"if settings.inactive or not DominosDB then return end", -- Not using
	"local Dom = DominosDB.profiles.FauxMazzle",
	"if not Dom then return end", -- something wrong so scram
	"local numbuttons = settings.numbuttons",
	"if (numbuttons == 12 and Dom.frames[3].hidden == true) or (numbuttons-12) == Dom.frames[3].columns then",
	"        return",
	"end",
	"numbuttons = numbuttons - 12",
	"if numbuttons == 0 then",
	"        Dom.frames[3].hidden = true",
	"        Dom.frames[6].hidden = true",
	"        Dom.frames[3].columns = 5",
	"        Dom.frames.class.anchor = '1TR'",
	"        Dom.frames.pet.anchor = '4TL'",
	"else",
	"        Dom.frames[3].hidden = false",
	"        Dom.frames[6].hidden = false",
	"        Dom.frames[3].columns = numbuttons",
	"        Dom.frames[6].columns = numbuttons",
	"        Dom.frames[3].numButtons = numbuttons * 2",
	"        Dom.frames[6].numButtons = numbuttons * 2",
	"        Dom.frames.class.anchor = '3TR'",
	"        Dom.frames.pet.anchor = '6TL'",
	"end",
	"Dominos:Unload()",
 	"Dominos.db:SetProfile('FauxMazzle')",
	"Dominos:Load()",
}
NS:DefaultsAddonConfigAdd(AddonName, ConfigVersion, ConfigFunc)

local function AssignDOM(reset)
	if not IsAddOnLoaded(AddonName) then 
		NS:GetSettings("Addons")[AddonName].inactive = true
		return 
	end
	local Settings = NS:GetSettings("Addons")[AddonName]
	Settings.configs = true
	Settings.numbuttons = 12
	Dominos:Unload() -- Dominos doesn't actually unload/set/load if the profile name is the same as current
 	Dominos.db:SetProfile("FauxMazzle")
	Dominos:Load()
	local Dom = DominosDB.profiles.FauxMazzle
	Dom.frames[3].hidden = false
--	NS:GetOption("InitialiseAddons")()
end

local function SetAnchor(scale)
	local UIScale = 1
	local ScreenWidth = NS.UIW * 0.5
	local MinimapWidth = (NS:GetFrame("Base", "Minimap"):GetWidth() * 0.5)
	if GetExpansionLevel() >= 8 then
		MinimapWidth = MinimapWidth * (0.5 - UIParent:GetEffectiveScale())
	end
	local DomWidth = DominosFrame5:GetWidth()
	local MenuY = DominosFramemenu:GetWidth() * 0.5
	if scale then
		UIScale = 2 - UIParent:GetScale()
		MenuY = MenuY * scale
	end
	local Dom = DominosDB.profiles.FauxMazzle
	local Offset = (((DomWidth / 2) + MinimapWidth) * UIScale) + 5 -- ScreenWidth - DomWidth --(DomWidth - MinimapWidth)-- - 6
	Dom.frames[2].x = Offset
	Dom.frames[5].x = -Offset
	Dom.frames.menu.y = -MenuY
	if not Dom.frames[3].hidden then
		Dom.frames.class.anchor = "1TR"
		Dom.frames.pet.anchor = "4TL"
	else
		Dom.frames.class.anchor = "3TR"
		Dom.frames.pet.anchor = "6TL"
	end
end

local function ConfigureDOM(reset)
	if not IsAddOnLoaded(AddonName) then 
		NS.DebugPrint("Not Found:", AddonName)
		return
	end
	local Scale, Yos
	if NS.Versions[AddonName][WOW_PROJECT_ID] and NS.Versions[AddonName][WOW_PROJECT_ID].scale then
		Scale = NS.Versions[AddonName][WOW_PROJECT_ID].scale
		Yos =  NS.Versions[AddonName][WOW_PROJECT_ID].yos
	end
	if DominosFrame5 then -- NS:IsValidVersion
		hooksecurefunc(DominosFrame5, "TrySetSize", function()
			SetAnchor(Scale)
			SetAnchor = function() end
		end)
	end
	local FauxMazzle = NS:LoadSettingsDOM()	
	DominosDB.profiles.FauxMazzle = {}
	local Dom = DominosDB.profiles.FauxMazzle
	if Scale then
		for k, v in pairs(FauxMazzle.frames) do
			if type(v) == "table" and v.scale then
				v.scale = v.scale * Scale -- * scale is to change value proportianly, not abolutely
				if v.y and v.y > 0 and Yos then
					v.y = v.y * Yos
				end
			end
		end
	end
	if WOW_PROJECT_ID == WOW_PROJECT_MAINLINE then
		for k, v in pairs(FauxMazzle.frames[1].pages) do
			v.dragonriding = 10
		end
	end
	NS.Lib:CopyTable(FauxMazzle, Dom)
	FauxMazzle = nil
	-- Lock the action bars and set SHIFT key to move
	SetCVar("lockActionBars", "1") 
	SetModifiedClick("PICKUPACTION", "SHIFT")
	local SaveBindings = SaveBindings or AttemptToSaveBindings
--	if NS:IsValidVersion(NS.WOW_Project.Classic) then
--		AttemptToSaveBindings(GetCurrentBindingSet())
--	else
		SaveBindings(GetCurrentBindingSet())
--	end

	NS:DefaultsAddonConfigInitialise(AddonName)
end
NS:AddConfig(1, AddonName, AddonName, ConfigureDOM, AssignDOM)

local function DOMOptions(parent, addonlistentry)
	if addonlistentry.frame then
		addonlistentry.frame:Show()
		return addonlistentry.frame
	end
	local L = NS.TEXTS
	local Container = CreateFrame("Frame", "DOMOptions", parent)
	NS.AddBackground(Container)
	Container:SetSize(120, parent:GetHeight())
--	Container:SetPoint("TOPRIGHT", offset, -15)
	local ButtonCount = {
		{ text="12", value=12, },
		{ text="13", value=13, },
		{ text="14", value=14, },
		{ text="15", value=15, },
		{ text="16", value=16, },
	}

	Container.NumButtons = NS:CreateDropList("NumButtons", Container, NS:GetSettings("Addons")[AddonName], "numbuttons", ButtonCount, "text", "value")
--	Container.NumButtons:AddPadding(50)
	Container.NumButtons:SetLabel(L.NumButtons, "TOP", 0, 5)
	Container.NumButtons:SetSize(100, 23)
	Container.NumButtons:SetPoint("TOPLEFT", 10, -25)
	Container.NumButtons.PostUpdate = function(self)
		NS:GetOption("InitialiseAddons")(nil, AddonName)
	end
	return Container
end
NS:RegisterAddonOptions(AddonName, DOMOptions)
